@@ -1,30 +1,32 @@
-#line 1 "inc/Module/Install/Share.pm - /usr/local/share/perl/5.8.4/Module/Install/Share.pm"
+#line 1
 package Module::Install::Share;
 
-use Module::Install::Base;
-@ISA = qw(Module::Install::Base);
-
-$VERSION = '0.01';
+BEGIN {
+	$VERSION = '0.60';
+	@ISA     = qw{Module::Install::Base};
+}
 
 use strict;
+use Module::Install::Base;
 
 sub install_share {
-    my $self = shift;
-    my $dir  = shift;
+    my ($self, $dir) = @_;
 
     if ( ! defined $dir ) {
         die "Cannot find the 'share' directory" unless -d 'share';
         $dir = 'share';
     }
 
-    $self->postamble(<<".");
+    $self->postamble(<<"END_MAKEFILE");
 config ::
 \t\$(NOECHO) \$(MOD_INSTALL) \\
-\t\t\"$dir\" \$(INST_ARCHAUTODIR)
+\t\t\"$dir\" \$(INST_AUTODIR)
 
-.
+END_MAKEFILE
 }
 
+1;
+
 __END__
 
-#line 62
+#line 90
